## Version 0.0.66

This new version introduces the Semantic Line Breaks (SEMBR) functionality to the blog summary and a new command. It enhances the readability and maintainability of the blog posts by applying a consistent line break strategy.

### New Features

- Added SEMBR functionality to blog summary in the `summarize` function (faa08e) (Eric Ma)
- Introduced a new command `sembr` that allows users to apply SEMBR to their blog posts (faa08e) (Eric Ma)
- Implemented SEMBR functionality using a new `sembr_bot` in the `prompt_library` (faa08e) (Eric Ma)
- Created a new file `prompt_library/sembr.py` to handle the SEMBR prompts and bot creation (faa08e) (Eric Ma)

### Bug Fixes

- None in this release

### Deprecations

- None in this release
